@@ -87,7 +87,7 @@ def setup_scons_lint(scons_env, target):
     scons_env.bbricks_target = target
 
     linter = SCons.Builder.Builder(
-        action=['$PYTHON $LINT $LINT_OPTIONS $SOURCE','date > $TARGET'],
+        action=['$LINT $LINT_OPTIONS $SOURCE','date > $TARGET'],
         suffix='.lint',
         src_suffix='.cpp')
 
